/**
 *****************************************************************************
   @example  SysTick.c
   @brief    Example of how to use the SysTick timer on the ADuCM360.

   @version V0.1
   @author  ADI
   @date    August 2017

   @par     Revision History:

All files for ADuCM360/361 provided by ADI, including this file, are
provided  as is without warranty of any kind, either expressed or implied.
The user assumes any and all risk from the use of this code.
It is the responsibility of the person integrating this code into an application
to ensure that the resulting application performs as required and is safe.
**/

#include <ADuCM360.h>
#include "SysTick.h"
#include "DioLib.h"
#include "WdtLib.h"
#include "ClkLib.h"
// ----------------------------------------------------------------------------
volatile uint32_t timer_delayCount;
// ----------------------------------------------------------------------------

void timer_start (void)
{
	//Update SystemCoreClock variable before using it.
	SystemCoreClockUpdate();
    // Use SysTick as reference for the delay loops.
    SysTick_Config (SystemCoreClock / TIMER_FREQUENCY_HZ);
}

void timer_sleep (uint32_t ticks)
{
   timer_delayCount = ticks;

   // Busy wait until the SysTick decrements the counter to zero.
   while (timer_delayCount != 0u);
}

void timer_tick (void)
{
   // Decrement to zero the counter used by the delay routine.
   if (timer_delayCount != 0) {
      --timer_delayCount;
   }
}

// ----- SysTick_Handler() ----------------------------------------------------
void  SysTick_Handler (void)
{
   timer_tick ();
}

// ----------------------------------------------------------------------------

int main(int argc, char *argv[])
{
	WdtCfg(T3CON_PRE_DIV1,T3CON_IRQ_EN,T3CON_PD_DIS); // Disable Watchdog timer resets
	//Disable clock to unused peripherals
	ClkDis(CLKDIS_DISSPI0CLK|CLKDIS_DISSPI1CLK|CLKDIS_DISI2CCLK|CLKDIS_DISPWMCLK|CLKDIS_DIST0CLK|CLKDIS_DIST1CLK|CLKDIS_DISDMACLK);
	ClkCfg(CLK_CD0,CLK_HF,CLKSYSDIV_DIV2EN_DIS,CLK_UCLKCG);            // Select CD0 for CPU clock
	ClkSel(CLK_CD6,CLK_CD7,CLK_CD0,CLK_CD7);     // Select CD0 for UART System clock

	/* Set the digital outputs for the LEDs */
	DioOen(pADI_GP0, GP0OEN_OEN4_OUT | GP0OEN_OEN5_OUT);

	/* Set up the SysTick timer */
	timer_start();

	while(1)
	{
		/* sleep 1 second */
		timer_sleep(1000);
		/* Toggle P0.4 - LED2, P0.5 - LED3 */
		DioTgl(pADI_GP0, GPTGL_TGL4 | GPTGL_TGL5);
	}
}
